package fr.iut.pm.movieapplication.ui.fragments

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.AdapterView
import android.widget.ArrayAdapter
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import fr.iut.pm.movieapplication.R
import fr.iut.pm.movieapplication.databinding.FragmentMoviesBinding
import fr.iut.pm.movieapplication.ui.adapter.MovieAdapter
import fr.iut.pm.movieapplication.ui.dialog.MovieDialog
import fr.iut.pm.movieapplication.ui.interfaces.MovieSelection
import fr.iut.pm.movieapplication.ui.viewmodel.MoviesVM

class MoviesFragment(
) : Fragment(), MovieSelection {

    private val moviesVM by viewModels<MoviesVM>()
    val moviesAdapter = MovieAdapter(this)
    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        val binding = FragmentMoviesBinding.inflate(inflater)
        binding.moviesVM = moviesVM
        binding.lifecycleOwner = viewLifecycleOwner

        with(binding.moviesItemRecyclerView) {
            adapter = moviesAdapter
        }

        val adapter = ArrayAdapter.createFromResource(
            requireContext(),
            R.array.movie_filter,
            android.R.layout.simple_spinner_item
        )
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)

        with(binding.categoryMovieSpinner)
        {
            this.adapter = adapter
            onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
                override fun onItemSelected(
                    parent: AdapterView<*>?,
                    view: View?,
                    position: Int,
                    id: Long
                ) {
                    moviesVM.getData(selectedItem.toString())
                }


                override fun onNothingSelected(parent: AdapterView<*>?) {
                    TODO("Not yet implemented")
                }

            }
        }
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        moviesVM.getMoviesLiveData().observe(viewLifecycleOwner) {
            moviesAdapter.submitList(it)
        }
    }

    override fun onMovieSelected(movieId: Int) {
        val dialog = MovieDialog()
        val args = Bundle()
        args.putInt("movieId",movieId)
        dialog.arguments = args
        dialog.show(parentFragmentManager, "tag")
    }
}
